# Module: tide

Top-level exports from `src/tide/__init__.py`.
TODO: Add signatures and usage examples for each item.

## Modules
- callbacks
- resampling
- cfl
- padding
- validation
- maxwell
- staggered
- utils
- wavelets

## Classes
- MaxwellTM
- CallbackState

## Types
- Callback

## Functions
- maxwelltm
- create_callback_state
- upsample
- downsample
- downsample_and_movedim
- cfl_condition
- validate_model_gradient_sampling_interval
- validate_freq_taper_frac
- validate_time_pad_frac
- create_or_pad
- zero_interior
- reverse_pad
- ricker
